@@ -26,9 +26,8 @@
 
 #include <gal/e-table/e-table-memory.h>
 #include <gal/e-table/e-table-memory-callbacks.h>
-#include <libgnome/gnome-defs.h>
 
-BEGIN_GNOME_DECLS
+G_BEGIN_DECLS
 
 #define E_TABLE_MEMORY_STORE_TYPE        (e_table_memory_store_get_type ())
 #define E_TABLE_MEMORY_STORE(o)          (GTK_CHECK_CAST ((o), E_TABLE_MEMORY_STORE_TYPE, ETableMemoryStore))
@@ -113,26 +112,10 @@ void         e_table_memory_store_insert_adopt_array  (ETableMemoryStore
 						       int                           row,
 						       void                        **store,
 						       gpointer                      data);
-void         e_table_memory_store_change_array        (ETableMemoryStore            *etms,
-						       int                           row,
-						       void                        **store,
-						       gpointer                      data);
-void         e_table_memory_store_change              (ETableMemoryStore            *etms,
-						       int                           row,
-						       gpointer                      data,
-						       ...);
-void         e_table_memory_store_change_adopt        (ETableMemoryStore            *etms,
-						       int                           row,
-						       gpointer                      data,
-						       ...);
-void         e_table_memory_store_change_adopt_array  (ETableMemoryStore            *etms,
-						       int                           row,
-						       void                        **store,
-						       gpointer                      data);
 void         e_table_memory_store_remove              (ETableMemoryStore            *etms,
 						       int                           row);
 void         e_table_memory_store_clear               (ETableMemoryStore            *etms);
 
-END_GNOME_DECLS
+G_END_DECLS
 
 #endif /* _E_TABLE_MEMORY_STORE_H_ */
