@@ -22,19 +22,20 @@
  */
 
 #include <config.h>
-#include <glib-object.h>
+#include <gtk/gtksignal.h>
 #include "e-table-model.h"
 #include "gal/util/e-util.h"
-#include "gal/util/e-marshal.h"
 
-#define ETM_CLASS(e) (E_TABLE_MODEL_GET_CLASS (e))
+#define ETM_CLASS(e) ((ETableModelClass *)(GTK_OBJECT_GET_CLASS (e)))
+
+#define PARENT_TYPE gtk_object_get_type ()
 
 #define d(x)
 
 d(static gint depth = 0;)
 
 
-static GObjectClass *e_table_model_parent_class;
+static GtkObjectClass *e_table_model_parent_class;
 
 enum {
 	MODEL_NO_CHANGE,
@@ -264,83 +265,78 @@ e_table_model_value_to_string (ETableModel *e_table_model, int col, const void *
 }
 
 static void
-e_table_model_finalize (GObject *object)
+e_table_model_destroy (GtkObject *object)
 {
-	if (e_table_model_parent_class->finalize)
-		(*e_table_model_parent_class->finalize)(object);
+	if (e_table_model_parent_class->destroy)
+		(*e_table_model_parent_class->destroy)(object);
 }
 
 static void
-e_table_model_class_init (GObjectClass *object_class)
+e_table_model_class_init (GtkObjectClass *object_class)
 {
 	ETableModelClass *klass = E_TABLE_MODEL_CLASS(object_class);
-	e_table_model_parent_class = g_type_class_peek_parent (object_class);
+	e_table_model_parent_class = gtk_type_class (PARENT_TYPE);
 	
-	object_class->finalize = e_table_model_finalize;
+	object_class->destroy = e_table_model_destroy;
 
 	e_table_model_signals [MODEL_NO_CHANGE] =
-		g_signal_new ("model_no_change",
-			      E_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ETableModelClass, model_no_change),
-			      (GSignalAccumulator) NULL, NULL,
-			      g_cclosure_marshal_VOID__VOID,
-			      G_TYPE_NONE, 0);
+		gtk_signal_new ("model_no_change",
+				GTK_RUN_LAST,
+				E_OBJECT_CLASS_TYPE (object_class),
+				GTK_SIGNAL_OFFSET (ETableModelClass, model_no_change),
+				gtk_marshal_NONE__NONE,
+				GTK_TYPE_NONE, 0);
 
 
 	e_table_model_signals [MODEL_CHANGED] =
-		g_signal_new ("model_changed",
-			      E_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ETableModelClass, model_changed),
-			      (GSignalAccumulator) NULL, NULL,
-			      g_cclosure_marshal_VOID__VOID,
-			      G_TYPE_NONE, 0);
+		gtk_signal_new ("model_changed",
+				GTK_RUN_LAST,
+				E_OBJECT_CLASS_TYPE (object_class),
+				GTK_SIGNAL_OFFSET (ETableModelClass, model_changed),
+				gtk_marshal_NONE__NONE,
+				GTK_TYPE_NONE, 0);
 
 	e_table_model_signals [MODEL_PRE_CHANGE] =
-		g_signal_new ("model_pre_change",
-			      E_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ETableModelClass, model_pre_change),
-			      (GSignalAccumulator) NULL, NULL,
-			      g_cclosure_marshal_VOID__VOID,
-			      G_TYPE_NONE, 0);
+		gtk_signal_new ("model_pre_change",
+				GTK_RUN_LAST,
+				E_OBJECT_CLASS_TYPE (object_class),
+				GTK_SIGNAL_OFFSET (ETableModelClass, model_pre_change),
+				gtk_marshal_NONE__NONE,
+				GTK_TYPE_NONE, 0);
 
 	e_table_model_signals [MODEL_ROW_CHANGED] =
-		g_signal_new ("model_row_changed",
-			      E_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ETableModelClass, model_row_changed),
-			      (GSignalAccumulator) NULL, NULL,
-			      g_cclosure_marshal_VOID__INT,
-			      G_TYPE_NONE, 1, G_TYPE_INT);
+		gtk_signal_new ("model_row_changed",
+				GTK_RUN_LAST,
+				E_OBJECT_CLASS_TYPE (object_class),
+				GTK_SIGNAL_OFFSET (ETableModelClass, model_row_changed),
+				gtk_marshal_NONE__INT,
+				GTK_TYPE_NONE, 1, GTK_TYPE_INT);
 
 	e_table_model_signals [MODEL_CELL_CHANGED] =
-		g_signal_new ("model_cell_changed",
-			      E_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ETableModelClass, model_cell_changed),
-			      (GSignalAccumulator) NULL, NULL,
-			      e_marshal_VOID__INT_INT,
-			      G_TYPE_NONE, 2, G_TYPE_INT, G_TYPE_INT);
+		gtk_signal_new ("model_cell_changed",
+				GTK_RUN_LAST,
+				E_OBJECT_CLASS_TYPE (object_class),
+				GTK_SIGNAL_OFFSET (ETableModelClass, model_cell_changed),
+				gtk_marshal_NONE__INT_INT,
+				GTK_TYPE_NONE, 2, GTK_TYPE_INT, GTK_TYPE_INT);
 
 	e_table_model_signals [MODEL_ROWS_INSERTED] =
-		g_signal_new ("model_rows_inserted",
-			      E_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ETableModelClass, model_rows_inserted),
-			      (GSignalAccumulator) NULL, NULL,
-			      e_marshal_VOID__INT_INT,
-			      G_TYPE_NONE, 2, G_TYPE_INT, G_TYPE_INT);
+		gtk_signal_new ("model_rows_inserted",
+				GTK_RUN_LAST,
+				E_OBJECT_CLASS_TYPE (object_class),
+				GTK_SIGNAL_OFFSET (ETableModelClass, model_rows_inserted),
+				gtk_marshal_NONE__INT_INT,
+				GTK_TYPE_NONE, 2, GTK_TYPE_INT, GTK_TYPE_INT);
 
 	e_table_model_signals [MODEL_ROWS_DELETED] =
-		g_signal_new ("model_rows_deleted",
-			      E_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ETableModelClass, model_rows_deleted),
-			      (GSignalAccumulator) NULL, NULL,
-			      e_marshal_VOID__INT_INT,
-			      G_TYPE_NONE, 2, G_TYPE_INT, G_TYPE_INT);
+		gtk_signal_new ("model_rows_deleted",
+				GTK_RUN_LAST,
+				E_OBJECT_CLASS_TYPE (object_class),
+				GTK_SIGNAL_OFFSET (ETableModelClass, model_rows_deleted),
+				gtk_marshal_NONE__INT_INT,
+				GTK_TYPE_NONE, 2, GTK_TYPE_INT, GTK_TYPE_INT);
+
+	E_OBJECT_CLASS_ADD_SIGNALS (object_class, e_table_model_signals, LAST_SIGNAL);
 
 	klass->column_count        = NULL;     
 	klass->row_count           = NULL;        
@@ -369,7 +365,31 @@ e_table_model_class_init (GObjectClass *object_class)
 	klass->model_rows_deleted  = NULL;
 }
 
-E_MAKE_TYPE(e_table_model, "ETableModel", ETableModel, e_table_model_class_init, NULL, G_TYPE_OBJECT)
+
+GtkType
+e_table_model_get_type (void)
+{
+	static guint type = 0;
+	
+	if (!type)
+	{
+		GtkTypeInfo info =
+		{
+			"ETableModel",
+			sizeof (ETableModel),
+			sizeof (ETableModelClass),
+			(GtkClassInitFunc) e_table_model_class_init,
+			NULL,
+			/* reserved_1 */ NULL,
+			/* reserved_2 */ NULL,
+			(GtkClassInitFunc) NULL,
+		};
+		
+		type = gtk_type_unique (PARENT_TYPE, &info);
+	}
+
+  return type;
+}
 
 #if d(!)0
 static void
@@ -390,8 +410,8 @@ e_table_model_pre_change (ETableModel *e_table_model)
 	d(print_tabs());
 	d(g_print("Emitting pre_change on model 0x%p, a %s.\n", e_table_model, gtk_type_name (GTK_OBJECT(e_table_model)->klass->type)));
 	d(depth++);
-	g_signal_emit (G_OBJECT (e_table_model), 
-		       e_table_model_signals [MODEL_PRE_CHANGE], 0);
+	gtk_signal_emit (GTK_OBJECT (e_table_model),
+			 e_table_model_signals [MODEL_PRE_CHANGE]);
 	d(depth--);
 }
 
@@ -417,8 +437,8 @@ e_table_model_no_change (ETableModel *e_table_model)
 	d(print_tabs());
 	d(g_print("Emitting model_no_change on model 0x%p, a %s.\n", e_table_model, gtk_type_name (GTK_OBJECT(e_table_model)->klass->type)));
 	d(depth++);
-	g_signal_emit (G_OBJECT (e_table_model),
-		       e_table_model_signals [MODEL_NO_CHANGE], 0);
+	gtk_signal_emit (GTK_OBJECT (e_table_model),
+			 e_table_model_signals [MODEL_NO_CHANGE]);
 	d(depth--);
 }
 
@@ -444,8 +464,8 @@ e_table_model_changed (ETableModel *e_table_model)
 	d(print_tabs());
 	d(g_print("Emitting model_changed on model 0x%p, a %s.\n", e_table_model, gtk_type_name (GTK_OBJECT(e_table_model)->klass->type)));
 	d(depth++);
-	g_signal_emit (G_OBJECT (e_table_model),
-		       e_table_model_signals [MODEL_CHANGED], 0);
+	gtk_signal_emit (GTK_OBJECT (e_table_model),
+			 e_table_model_signals [MODEL_CHANGED]);
 	d(depth--);
 }
 
@@ -468,8 +488,8 @@ e_table_model_row_changed (ETableModel *e_table_model, int row)
 	d(print_tabs());
 	d(g_print("Emitting row_changed on model 0x%p, a %s, row %d.\n", e_table_model, gtk_type_name (GTK_OBJECT(e_table_model)->klass->type), row));
 	d(depth++);
-	g_signal_emit (G_OBJECT (e_table_model),
-		       e_table_model_signals [MODEL_ROW_CHANGED], 0, row);
+	gtk_signal_emit (GTK_OBJECT (e_table_model),
+			 e_table_model_signals [MODEL_ROW_CHANGED], row);
 	d(depth--);
 }
 
@@ -493,8 +513,8 @@ e_table_model_cell_changed (ETableModel *e_table_model, int col, int row)
 	d(print_tabs());
 	d(g_print("Emitting cell_changed on model 0x%p, a %s, row %d, col %d.\n", e_table_model, gtk_type_name (GTK_OBJECT(e_table_model)->klass->type), row, col));
 	d(depth++);
-	g_signal_emit (G_OBJECT (e_table_model),
-		       e_table_model_signals [MODEL_CELL_CHANGED], 0, col, row);
+	gtk_signal_emit (GTK_OBJECT (e_table_model),
+			 e_table_model_signals [MODEL_CELL_CHANGED], col, row);
 	d(depth--);
 }
 
@@ -518,8 +538,8 @@ e_table_model_rows_inserted (ETableModel *e_table_model, int row, int count)
 	d(print_tabs());
 	d(g_print("Emitting row_inserted on model 0x%p, a %s, row %d.\n", e_table_model, gtk_type_name (GTK_OBJECT(e_table_model)->klass->type), row));
 	d(depth++);
-	g_signal_emit (G_OBJECT (e_table_model),
-		       e_table_model_signals [MODEL_ROWS_INSERTED], 0, row, count);
+	gtk_signal_emit (GTK_OBJECT (e_table_model),
+			 e_table_model_signals [MODEL_ROWS_INSERTED], row, count);
 	d(depth--);
 }
 
@@ -558,8 +578,8 @@ e_table_model_rows_deleted (ETableModel *e_table_model, int row, int count)
 	d(print_tabs());
 	d(g_print("Emitting row_deleted on model 0x%p, a %s, row %d.\n", e_table_model, gtk_type_name (GTK_OBJECT(e_table_model)->klass->type), row));
 	d(depth++);
-	g_signal_emit (G_OBJECT (e_table_model),
-		       e_table_model_signals [MODEL_ROWS_DELETED], 0, row, count);
+	gtk_signal_emit (GTK_OBJECT (e_table_model),
+			 e_table_model_signals [MODEL_ROWS_DELETED], row, count);
 	d(depth--);
 }
 
