@@ -34,7 +34,6 @@
 #include <gal/e-table/e-table-specification.h>
 #include <gal/e-table/e-table-state.h>
 #include <gal/e-table/e-tree-model.h>
-#include <gal/e-table/e-tree-table-adapter.h>
 
 #define E_TREE_USE_TREE_SELECTION
 
@@ -45,10 +44,11 @@
 G_BEGIN_DECLS
 
 #define E_TREE_TYPE        (e_tree_get_type ())
-#define E_TREE(o)          (G_TYPE_CHECK_INSTANCE_CAST ((o), E_TREE_TYPE, ETree))
-#define E_TREE_CLASS(k)    (G_TYPE_CHECK_CLASS_CAST((k), E_TREE_TYPE, ETreeClass))
-#define E_IS_TREE(o)       (G_TYPE_CHECK_INSTANCE_TYPE ((o), E_TREE_TYPE))
-#define E_IS_TREE_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), E_TREE_TYPE))
+#define E_TREE(o)          (GTK_CHECK_CAST ((o), E_TREE_TYPE, ETree))
+#define E_TREE_CLASS(k)    (GTK_CHECK_CLASS_CAST((k), E_TREE_TYPE, ETreeClass))
+#define E_IS_TREE(o)       (GTK_CHECK_TYPE ((o), E_TREE_TYPE))
+#define E_IS_TREE_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), E_TREE_TYPE))
+
 typedef struct _ETreeDragSourceSite ETreeDragSourceSite;
 typedef struct ETreePriv ETreePriv;
 
@@ -136,7 +136,7 @@ typedef struct {
 						 guint               time);
 } ETreeClass;
 
-GType           e_tree_get_type                   (void);
+GtkType         e_tree_get_type                   (void);
 ETree          *e_tree_construct                  (ETree                *e_tree,
 						   ETreeModel           *etm,
 						   ETableExtras         *ete,
@@ -166,8 +166,6 @@ ETableState    *e_tree_get_state_object           (ETree                *e_tree)
 ETableSpecification    *e_tree_get_spec           (ETree                *e_tree);
 
 /* note that it is more efficient to provide the state at creation time */
-void            e_tree_set_search_column          (ETree *e_tree,
-						   gint  col);
 void            e_tree_set_state                  (ETree                *e_tree,
 						   const gchar          *state);
 void            e_tree_set_state_object           (ETree                *e_tree,
@@ -216,7 +214,6 @@ void            e_tree_get_cell_geometry          (ETree                *tree,
 /* Useful accessors */
 ETreeModel *    e_tree_get_model                  (ETree *et);
 ESelectionModel *e_tree_get_selection_model       (ETree *et);
-ETreeTableAdapter *e_tree_get_table_adapter       (ETree *et);
 
 /* Drag & drop stuff. */
 /* Target */
