@@ -45,40 +45,27 @@
 #endif
 
 int
-g_str_compare (const void *x, const void *y)
+g_str_compare(const void *x, const void *y)
 {
 	if (x == NULL || y == NULL) {
 		if (x == y)
 			return 0;
 		else
 			return x ? -1 : 1;
-	}
-	
-	return strcmp (x, y);
+	} 
+		
+	return strcmp(x, y);
 }
 
 int
-g_collate_compare (const void *x, const void *y)
+g_int_compare(const void *x, const void *y)
 {
-	if (x == NULL || y == NULL) {
-		if (x == y)
-			return 0;
-		else
-			return x ? -1 : 1;
-	}
-	
-	return g_utf8_collate (x, y);
-}
-
-int
-g_int_compare (const void *x, const void *y)
-{
-	if (GPOINTER_TO_INT (x) < GPOINTER_TO_INT (y))
-		return -1;
-	else if (GPOINTER_TO_INT (x) == GPOINTER_TO_INT (y))
-		return 0;
-	else
-		return 1;
+  if ( GPOINTER_TO_INT(x) < GPOINTER_TO_INT(y) )
+    return -1;
+  else if ( GPOINTER_TO_INT(x) == GPOINTER_TO_INT(y) )
+    return 0;
+  else
+    return 1;
 }
 
 char *
@@ -104,7 +91,7 @@ e_free_object_list (GList *list)
 	GList *p;
 
 	for (p = list; p != NULL; p = p->next)
-		g_object_unref (p->data);
+		gtk_object_unref (GTK_OBJECT (p->data));
 
 	g_list_free (list);
 }
@@ -115,7 +102,7 @@ e_free_object_slist (GSList *list)
 	GSList *p;
 
 	for (p = list; p != NULL; p = p->next)
-		g_object_unref (p->data);
+		gtk_object_unref (GTK_OBJECT (p->data));
 
 	g_slist_free (list);
 }
@@ -198,7 +185,7 @@ e_write_file(const char *filename, const char *data, int flags)
 	int fd;
 	int length = strlen(data);
 	int bytes;
-	fd = open(filename, flags | O_WRONLY, 0666);
+	fd = open(filename, flags, 0666);
 	if (fd == -1)
 		return errno;
 	while (length > 0) {
@@ -237,7 +224,7 @@ e_write_file_mkstemp(char *filename, const char *data)
 		} else {
 			if (errno != EINTR && errno != EAGAIN) {
 				int save_errno = errno;
-				close(fd);
+	close(fd);
 				return save_errno;
 			}
 		}
@@ -275,8 +262,11 @@ e_mkdir_hier(const char *path, mode_t mode)
 		p = strchr (p + 1, '/');
 		if (p)
 			*p = '\0';
-		if (access (copy, F_OK) == -1) {
-			if (mkdir (copy, mode) == -1) {
+		if (mkdir (copy, mode) == -1) {
+			switch (errno) {
+			case EEXIST:
+				break;
+			default:
 				g_free (copy);
 				return -1;
 			}
@@ -418,20 +408,13 @@ e_strstrcase (const gchar *haystack, const gchar *needle)
 void
 e_filename_make_safe (gchar *string)
 {
-	gchar *p, *ts;
-	gunichar c;
+	gchar *p;
 	
 	g_return_if_fail (string != NULL);
-	p = string;
-
-	while(p && *p) {
-		c = g_utf8_get_char (p);
-		ts = p;
-		p = g_utf8_next_char (p);
-		if (!g_unichar_isprint(c) || ( c < 0xff && strchr (" /'\"`&();|<>$%{}!", c&0xff ))) {
-			while (ts<p) 	
-				*ts++ = '_';
-		}
+	
+	for (p = string; *p; p++) {
+		if (!isprint ((unsigned char)*p) || strchr (" /'\"`&();|<>${}!", *p))
+			*p = '_';
 	}
 }
 
@@ -775,42 +758,6 @@ size_t e_strftime(char *s, size_t max, const char *fmt, const struct tm *tm)
 #endif
 }
 
-size_t 
-e_utf8_strftime(char *s, size_t max, const char *fmt, const struct tm *tm)
-{
-	size_t sz, ret;
-	char *locale_fmt, *buf;
-
-	locale_fmt = g_locale_from_utf8(fmt, -1, NULL, &sz, NULL);
-	if (!locale_fmt)
-		return 0;
-
-	ret = e_strftime(s, max, locale_fmt, tm);
-	if (!ret) {
-		g_free (locale_fmt);
-		return 0;
-	}
-
-	buf = g_locale_to_utf8(s, ret, NULL, &sz, NULL);
-	if (!buf) {
-		g_free (locale_fmt);
-		return 0;
-	}
-
-	if (sz >= max) {
-		char *tmp = buf + max - 1;
-		tmp = g_utf8_find_prev_char(buf, tmp);
-		if (tmp)
-			sz = tmp - buf;
-		else
-			sz = 0;
-	}
-	memcpy(s, buf, sz);
-	s[sz] = '\0';
-	g_free(locale_fmt);
-	g_free(buf);
-	return sz;
-}
 
 /**
  * Function to do a last minute fixup of the AM/PM stuff if the locale
@@ -873,43 +820,6 @@ size_t e_strftime_fix_am_pm(char *s, size_t max, const char *fmt, const struct t
 	return(ret);
 }
 
-size_t 
-e_utf8_strftime_fix_am_pm(char *s, size_t max, const char *fmt, const struct tm *tm)
-{
-	size_t sz, ret;
-	char *locale_fmt, *buf;
-
-	locale_fmt = g_locale_from_utf8(fmt, -1, NULL, &sz, NULL);
-	if (!locale_fmt)
-		return 0;
-
-	ret = e_strftime_fix_am_pm(s, max, locale_fmt, tm);
-	if (!ret) {
-		g_free (locale_fmt);
-		return 0;
-	}
-
-	buf = g_locale_to_utf8(s, ret, NULL, &sz, NULL);
-	if (!buf) {
-		g_free (locale_fmt);
-		return 0;
-	}
-
-	if (sz >= max) {
-		char *tmp = buf + max - 1;
-		tmp = g_utf8_find_prev_char(buf, tmp);
-		if (tmp)
-			sz = tmp - buf;
-		else
-			sz = 0;
-	}
-	memcpy(s, buf, sz);
-	s[sz] = '\0';
-	g_free(locale_fmt);
-	g_free(buf);
-	return sz;
-}
-
 /**
  * e_flexible_strtod:
  * @nptr:    the string to convert to a numeric value.
@@ -1188,6 +1098,20 @@ e_strdup_append_strings (gchar *first_string, ...)
 	return buffer;
 }
 
+char *
+e_gettext (const char *msgid)
+{
+	static gboolean initialized = FALSE;
+
+	if (!initialized) {
+		bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+		bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+		initialized = TRUE;
+	}        
+
+	return dgettext (GETTEXT_PACKAGE, msgid);
+}
+
 gchar **
 e_strdupv (const gchar **str_array)
 {
@@ -1213,18 +1137,3 @@ e_strdupv (const gchar **str_array)
 		return NULL;
 	}
 }
-
-char *
-e_gettext (const char *msgid)
-{
-	static gboolean initialized = FALSE;
-
-	if (!initialized) {
-		bindtextdomain (E_I18N_DOMAIN, GNOMELOCALEDIR);
-		bind_textdomain_codeset (E_I18N_DOMAIN, "UTF-8");
-		initialized = TRUE;
-	}        
-
-	return dgettext (E_I18N_DOMAIN, msgid);
-}
-
