@@ -24,11 +24,10 @@
 #ifndef _E_CATEGORIES_MASTER_LIST_COMBO_H_
 #define _E_CATEGORIES_MASTER_LIST_COMBO_H_
 
-#include <libgnome/gnome-defs.h>
 #include <gal/widgets/e-categories-master-list.h>
 #include <gtk/gtkcombo.h>
 
-BEGIN_GNOME_DECLS
+G_BEGIN_DECLS
 
 #define E_CATEGORIES_MASTER_LIST_COMBO_TYPE        (e_categories_master_list_combo_get_type ())
 #define E_CATEGORIES_MASTER_LIST_COMBO(o)          (GTK_CHECK_CAST ((o), E_CATEGORIES_MASTER_LIST_COMBO_TYPE, ECategoriesMasterListCombo))
@@ -53,6 +52,6 @@ GtkWidget *e_categories_master_list_combo_new        (ECategoriesMasterList
 GtkWidget *e_categories_master_list_combo_construct  (ECategoriesMasterListCombo *ecmlc,
 						      ECategoriesMasterList      *ecml);
 
-END_GNOME_DECLS
+G_END_DECLS
 
 #endif /* _E_CATEGORIES_MASTER_LIST_COMBO_H */
